import { Request, Response } from "express";
import { Event } from "../models/event";
import { MONGODB_IGNORED_FIELDS } from "../utils/constants";

export async function CreateEvent(req: Request, res: Response) {
  try {
    const { name, type, latitude, longitude } = req.body;

    if (!name || type === null || !latitude || !longitude) {
      console.log("missing fields");
      return res.status(400).json({ status: "err" });
    }

    const event = new Event({
      name: name,
      type: type,
      latitude: latitude,
      longitude: longitude,
    });

    await event
      .save()
      .then(() => res.status(200).json({ status: "ok" }))
      .catch((err) => {
        console.log(err);
        res.status(500).json({ status: "err" });
      });
  } catch (error) {
    console.error("error on create event:", error);
    res.status(500).json({ status: "err" });
  }
}

export async function GetEvents(req: Request, res: Response) {
  try {
    const events = await Event.find().select(MONGODB_IGNORED_FIELDS).lean();

    res.status(200).json({ events });
  } catch (error) {
    console.error("error on get events:", error);
    res.status(500).json({ status: "err" });
  }
}
