import mongoose, { InferSchemaType, Schema } from "mongoose";
import { v4 as uuidv4 } from "uuid";

export interface IUser extends Document {
  userId: string;
  accountName: string;
  username: string;
  password: string;
  followers: number;
  following: number;
  visited: number;
  isAdmin: boolean;
  createdAt: Date;
}

export const userSchema = new Schema({
  userId: {
    type: String,
    required: true,
    unique: true,
    default: () => uuidv4(),
  },
  accountName: String,
  username: String,
  password: String,
  followers: {
    type: Number,
    default: 0,
  },
  following: {
    type: Number,
    default: 0,
  },
  visited: {
    type: Number,
    default: 0,
  },
  isAdmin: {
    type: Boolean,
    default: false,
  },
  createdAt: {
    type: Date,
    default: Date.now(),
  },
});

export type User = InferSchemaType<typeof userSchema>;

export const User = mongoose.model<IUser>("User", userSchema);
